include simpledll.e
include std/dll.e
include std/os.e
include std/machine.e
include std/types.e

--// Open libXOS
atom libXOSD = OpenDLL("/usr/local/lib/libxosdwrap.so")

-- Get all shared library routines
enum xosd_create, 
		xosd_destroy, 
		xosd_display,
		xosd_display_percentage,
		xosd_display_slider, 
		xosd_set_font, 
		xosd_set_shadow_offset,
		xosd_set_colour,
		xosd_set_outline_offset,
		xosd_set_outline_colour,
		xosd_show,
		xosd_hide,
		xosd_set_position,
		xosd_set_align,
		xosd_set_horizontal_offset,
		xosd_set_vertical_offset,
		xosd_scroll,
		xosd_set_timeout,
		xosd_wait_until_no_display,
		xosd_error 

-- Get all shared library routines
sequence routines = { {"Create",{C_INT},C_POINTER},
					  {"Destroy", {C_POINTER},C_INT},
					  {"Display", {C_POINTER,C_INT,C_POINTER}, C_INT},
					  {"DisplayPercentage", {C_POINTER,C_INT,C_INT}, C_INT},
					  {"DisplaySlider", {C_POINTER,C_INT,C_INT}, C_INT},					  					  
					  {"SetFont", {C_POINTER,C_POINTER}, C_INT},
					  {"SetShadowOffset", {C_POINTER,C_INT}, C_INT},
					  {"SetColour", {C_POINTER,C_POINTER}, C_INT},
					  {"SetOutlineOffset", {C_POINTER,C_INT}, C_INT},
					  {"SetOutlineColour", {C_POINTER,C_POINTER}, C_INT},
					  {"Show", {C_POINTER}, C_INT},
					  {"Hide", {C_POINTER}, C_INT},
					  {"SetPos",{C_POINTER,C_INT}, C_INT},
					  {"SetAlign",{C_POINTER,C_INT}, C_INT}, 
					  {"SetHorizontalOffset",{C_POINTER,C_INT}, C_INT},
					  {"SetVerticalOffset",{C_POINTER,C_INT}, C_INT},
					  {"Scroll",{C_POINTER,C_INT},C_INT},
					  {"SetTimeout",{C_POINTER,C_INT},C_INT},
					  {"WaitUntilNoDisplay",{C_POINTER},C_INT},
					  {"Error",{C_POINTER}} }

-- Get all shared library routines					  
sequence wrap =  DefineFuncProc(libXOSD,routines)	

public enum xosd_top,
			xosd_middle,
			xosd_bottom

public enum xosd_left,
			xosd_center,
			xosd_right

-- Wrap public routines for use in programs
---<>--------------------------------------
-- xosdCreate ( int numLines )
-------------------------------------------
public function xosdCreate(integer numLines)
	atom osd = c_func(wrap[xosd_create],{numLines})
	return osd
end function

---<>--------------------------------------
-- xosdDestroy ( atom osd )
-------------------------------------------
public function xosdDestroy(atom osd)
	return c_func(wrap[xosd_destroy],{osd})
end function

---<>--------------------------------------
-- xosdDisplay ( atom osd, integer line, sequence text )
-------------------------------------------
public function xosdDisplay(atom osd, integer line, sequence text) 
	if string(text) then
		atom textPtr = allocate_string(text,1)
		return c_func(wrap[xosd_display], {osd,line,textPtr})
	else
		return -1
	end if
end function

---<>--------------------------------------
-- xosdDisplayPercentage ( atom osd, integer line, integer percent )
-------------------------------------------
public function xosdDisplayPercentage(atom osd, integer line, integer percent) 
		return c_func(wrap[xosd_display_percentage], {osd,line,percent})
end function

---<>--------------------------------------
-- xosdDisplaySlider ( atom osd, integer line, integer slide )
-------------------------------------------
public function xosdDisplaySlider(atom osd, integer line, integer slide) 
		return c_func(wrap[xosd_display_slider], {osd,line,slide})
end function

---<>--------------------------------------
-- xosdSetFont ( atom osd, sequence font )
-------------------------------------------
public function xosdSetFont(atom osd, sequence font) 
	if string(font) then
		atom fontPtr = allocate_string(font,1)
		return c_func(wrap[xosd_set_font], {osd,fontPtr})
	else
		return -1
	end if
end function

---<>--------------------------------------
-- xosdSetShadowOffset ( atom osd, integer offset )
-------------------------------------------
public function xosdSetShadowOffset(atom osd, integer offset) 
	return c_func(wrap[xosd_set_shadow_offset], {osd,offset})
end function

---<>--------------------------------------
-- xosdSetColour ( atom osd, sequence color )
-------------------------------------------
public function xosdSetColour(atom osd, sequence color) 
	if string(color) then
		atom colorPtr = allocate_string(color,1)
		return c_func(wrap[xosd_set_colour],{osd,colorPtr})
	else
		return -1
	end if
end function

---<>--------------------------------------
-- xosdSetOutlineOffset ( atom osd, integer offset )
-------------------------------------------
public function xosdSetOutlineOffset(atom osd, integer offset) 
		return c_func(wrap[xosd_set_outline_offset],{osd,offset})
end function

---<>--------------------------------------
-- xosdSetOutlineColour ( atom osd, sequence color )
-------------------------------------------
public function xosdSetOutlineColour(atom osd, sequence color) 
	if string(color) then
		atom colorPtr = allocate_string(color,1)
		return c_func(wrap[xosd_set_outline_colour],{osd,colorPtr})
	else
		return -1
	end if
end function

---<>--------------------------------------
-- xosdShow ( atom osd )
-------------------------------------------
public function xosdShow(atom osd)
	return c_func(wrap[xosd_show], {osd} )
end function

---<>--------------------------------------
-- xosdHide ( atom osd )
-------------------------------------------
public function xosdHide(atom osd)
	return c_func(wrap[xosd_hide], {osd} )
end function

---<>--------------------------------------
-- xosdSetPosition ( atom osd, integer line, integer pos )
-------------------------------------------
public function xosdSetPosition(atom osd, integer pos) 
	return c_func(wrap[xosd_set_position], {osd,pos})
end function

---<>--------------------------------------
-- xosdDSetAlign ( atom osd, integer align )
-------------------------------------------
public function xosdSetAlign(atom osd, integer align) 
	return c_func(wrap[xosd_set_align], {osd,align})
end function

---<>--------------------------------------
-- xosdSetHorizontalOffset ( atom osd, integer offset )
-------------------------------------------
public function xosdSetHorizontalOffset(atom osd, integer offset) 
	return c_func(wrap[xosd_set_horizontal_offset], {osd,offset})
end function

---<>--------------------------------------
-- xosdSetVertcialOffset ( atom osd, integer offset )
-------------------------------------------
public function xosdSetVerticalOffset(atom osd, integer offset) 
	return c_func(wrap[xosd_set_vertical_offset], {osd,offset})
end function

---<>--------------------------------------
-- xosdScroll ( atom osd, integer scroll )
-------------------------------------------
public function xosdScroll(atom osd, integer scroll)
	return c_func(wrap[xosd_scroll], {osd,scroll} )
end function

---<>--------------------------------------
-- xosdSetTimeout ( atom osd, integer timeout )
-------------------------------------------
public function xosdSetTimeout(atom osd, integer timeout)
	return c_func(wrap[xosd_set_timeout], {osd,timeout} )
end function

---<>--------------------------------------
-- xosdWaitUntilNoDisplay ( atom osd )
-------------------------------------------
public function xosdWaitUntilNoDisplay(atom osd)
	return c_func(wrap[xosd_wait_until_no_display],{osd})
end function

---<>--------------------------------------
-- xosdError (  )
-------------------------------------------
public function xosdError()
	atom buffer = allocate(255)
	c_proc(wrap[xosd_error],{buffer})
	sequence errorMsg = peek_string(buffer)
	deallocate(buffer)
	return errorMsg
end function
